import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/hoverBuilder/hoverBuilder.dart';
import 'package:softcorp_flutter_core/text_theme/text_theme.dart';
import 'package:softcorp_flutter_core/constants.dart';

class CustomElevatedButton extends StatelessWidget {
  final String title;
  final double? width;
  final double? height;
  final Widget iconData;
  final Function()? onPressed;
  final Color? color;

  const CustomElevatedButton(this.title,
      {Key? key,
      required this.iconData,
      this.width,
      this.height,
      this.onPressed,
      this.color})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return RaiseOnHover(
      builder: (isHovered) {
        return SizedBox(
          width: width ?? 250,
          height: height ?? 55,
          child: ElevatedButton.icon(
            icon: iconData,
            style: ButtonStyle(
              shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(buttonCornerRadius),
                ),
              ),
              backgroundColor: MaterialStateProperty.resolveWith<Color>(
                (Set<MaterialState> states) {
                  if (states.contains(MaterialState.pressed)) {
                    return color ?? defaultDarkColor;
                  }
                  if (states.contains(MaterialState.hovered)) {
                    return color ?? defaultDarkColor;
                  }
                  return color ?? defaultDarkColor;
                },
              ),
            ),
            onPressed: onPressed,
            label:
                buttonText(text: title, context: context, color: Colors.white),
          ),
        );
      },
    );
  }
}
